@@ -1,20 +1,9 @@
-/***************************************************************************
-                          filters.h  -  description
-                             -------------------
-    begin                : Fri Jun 30 2000
-    copyright            : (C) 2000 by Hans Dijkema
-    email                : kmailcvt@hum.org
- ***************************************************************************/
+/*
+  SPDX-FileCopyrightText: 2000 Hans Dijkema <kmailcvt@hum.org>
+  SPDX-FileCopyrightText: 2012-2021 Laurent Montel <montel@kde.org>
 
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
-/* Copyright (c) 2012-2020 Laurent Montel <montel@kde.org>                      */
+  SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef FILTERS_H
 #define FILTERS_H
@@ -31,7 +20,8 @@
 
 #include <QDir>
 
-namespace MailImporter {
+namespace MailImporter
+{
 /**
  * @brief The Filter class
  * @author Laurent Montel <montel@kde.org>
@@ -67,7 +57,9 @@ public:
 
 protected:
     static int countDirectory(const QDir &dir, bool searchHiddenDirectory);
-    bool importMessage(const QString &folderName, const QString &msgPath, bool duplicateCheck, MailImporter::MessageStatus status = MailImporter::MessageStatus());
+    Q_REQUIRED_RESULT bool
+    importMessage(const QString &folderName, const QString &msgPath, bool duplicateCheck, const MessageStatus &status = MailImporter::MessageStatus());
+
 private:
     class Private;
     Private *const d;
